@@ -1,4 +1,6 @@
 import json
+import pandas
+import time
 from .mlmodel import MLModel
 
 
@@ -11,6 +13,8 @@ class DSAPIEncoder(json.JSONEncoder):
                 "experiment_id": str(obj.experiment_id)
             }
             return json_obj
+        if isinstance(obj, pandas.Timestamp):
+            return int(time.mktime(obj.timetuple()) * 1000)
         else:
             type_name = obj.__class__.__name__
-            raise TypeError("Unexpected type {0}".format(type_name))
\ No newline at end of file
+            raise TypeError("Unexpected type {0}".format(type_name))
