@@ -13,6 +13,7 @@ class Execution:
 
         # Execution = "wizard" automl or "simulate" execute trained wizatads
         self.execution_type = "wizard"
+        self.script = None
 
         self.request = request
         self.dataframe = None
@@ -42,3 +43,11 @@ class Execution:
 
         self.models.append(ml_model)
         return ml_model
+
+    def to_json(self):
+        obj = {}
+        if self.request is not None:
+            obj["request"] = self.request.prepare()
+        if self.script is not None:
+            obj["script"] = self.script.to_json()
+        return obj
