@@ -12,6 +12,7 @@ import sklearn
 from .request import Request
 from .mlmodel import MLModel
 from .script import Script
+from .execution import Execution
 from .dataframe_toolkit import DataFrameToolkit
 from .dsapi_json_encoder import DSAPIEncoder
 
@@ -100,3 +101,13 @@ class WizataDSAPIClient:
             return response.json()["script_id"]
         else:
             raise TypeError("Type not supported.")
+
+    def execute(self, obj):
+        if isinstance(obj, Execution):
+            response = requests.post(self.__url() + "execute",
+                                     headers=self.__header(),
+                                     data=json.dumps(obj.to_json()))
+            return response.json()
+        else:
+            raise TypeError("Type not supported.")
+
